@@ -9,7 +9,7 @@ from dateutil.parser import parse
 from pprint import pprint
 from tabulate import tabulate
 
-from . import git, iam
+from . import ecs, git, iam
 from .pretty_printing import pprint_date
 from .project import Projects
 from .version_check import warn_if_not_latest_version, current_version
@@ -154,8 +154,10 @@ def _deploy(project, release, environment_id, description, confirm=True):
     click.echo(click.style(f"Requested by: {release['requested_by']}", fg="yellow"))
     click.echo(click.style(f"Date created: {release['date_created']}", fg="yellow"))
 
-    ecs_service_arns = project.get_ecs_service_arns(
+    ecs_service_arns = ecs.find_service_arns_for_release(
+        project=project._underlying,
         release=release,
+        service_descriptions=project.ecs._described_services,
         environment_id=environment_id
     )
 
